@@ -28,14 +28,15 @@
 class KmtServiceInfo
 {
 public:
-    KmtServiceInfo(const QString &desktopEntryName, const QString &homepageUrl, int maxUrlArgCount)
-        : desktopEntryName(desktopEntryName), homepageUrl(homepageUrl), maxUrlArgCount(maxUrlArgCount)
+    KmtServiceInfo(const QString &desktopEntryName, const QString &homepageUrl, int maxUrlArgCount, const QString &appstreamId)
+        : desktopEntryName(desktopEntryName), homepageUrl(homepageUrl), maxUrlArgCount(maxUrlArgCount), appstreamId(appstreamId)
     {
     }
 public:
     QString desktopEntryName;
     QString homepageUrl;
     int maxUrlArgCount;
+    QString appstreamId;
 };
 
 //
@@ -45,7 +46,7 @@ KMoreToolsService* KMoreToolsPresets::registerServiceByDesktopEntryName(KMoreToo
 {
     static QHash<QString, KmtServiceInfo> dict;
 
-#define ADD_ENTRY(desktopEntryName, maxUrlArgCount, homepageUrl) dict.insert(desktopEntryName, KmtServiceInfo(desktopEntryName, QLatin1String(homepageUrl), maxUrlArgCount));
+#define ADD_ENTRY(desktopEntryName, maxUrlArgCount, homepageUrl, appstreamUrl) dict.insert(desktopEntryName, KmtServiceInfo(desktopEntryName, QLatin1String(homepageUrl), maxUrlArgCount, appstreamUrl));
 
     //
     // definitions begin (sorted alphabetically):
@@ -55,43 +56,43 @@ KMoreToolsService* KMoreToolsPresets::registerServiceByDesktopEntryName(KMoreToo
     //                                              |       arguments also lead to errors. Watch the console
     //                                              v       output for messages from the program.
     //
-    ADD_ENTRY("angrysearch",                        0, "https://github.com/DoTheEvo/ANGRYsearch");
-    ADD_ENTRY("com.uploadedlobster.peek",           0, "https://github.com/phw/peek"); // easy to use screen recorder, creates gif
-    ADD_ENTRY("catfish",                            1, "http://www.twotoasts.de/index.php/catfish/");
-    ADD_ENTRY("ding",                               0, "https://www-user.tu-chemnitz.de/~fri/ding/"); // Offline dict, Online: http://dict.tu-chemnitz.de/dings.cgi
-    ADD_ENTRY("disk",                               0, "https://en.opensuse.org/YaST_Disk_Controller");
-    ADD_ENTRY("fontinst",                           0, "https://docs.kde.org/trunk5/en/kde-workspace/kcontrol/fontinst/"); // good for previewing many fonts at once
-    ADD_ENTRY("fontmatrix",                         0, "https://github.com/fontmatrix/fontmatrix");
-    ADD_ENTRY("fsearch",                            0, "http://www.fsearch.org/");
-    ADD_ENTRY("giggle",                             1, "https://wiki.gnome.org/Apps/giggle/"); // good for searching in history
-    ADD_ENTRY("git-cola-folder-handler",            1, "https://git-cola.github.io");
-    ADD_ENTRY("git-cola-view-history.kmt-edition",  1, "https://git-cola.github.io");
-    ADD_ENTRY("gitk.kmt-edition",                   1, "http://git-scm.com/docs/gitk");
-    ADD_ENTRY("qgit.kmt-edition",                   1, "http://libre.tibirna.org/projects/qgit");
-    ADD_ENTRY("gitg",                               1, "https://wiki.gnome.org/action/show/Apps/Gitg?action=show&redirect=Gitg");
-    ADD_ENTRY("gnome-search-tool",                  0, "https://help.gnome.org/users/gnome-search-tool/"); // has good filtering options
-    ADD_ENTRY("gucharmap",                          0, "https://wiki.gnome.org/action/show/Apps/Gucharmap");
-    ADD_ENTRY("gparted",                            0, "http://gparted.org");
-    ADD_ENTRY("htop",                               0, "http://hisham.hm/htop/");
-    ADD_ENTRY("hotshots",                           1, "http://sourceforge.net/projects/hotshots/");
-    ADD_ENTRY("kaption",                            0, "http://kde-apps.org/content/show.php/?content=139302");
-    ADD_ENTRY("kding",                              0, ""); // Offline dict; unmaintained?
-    ADD_ENTRY("org.kde.kmousetool",                 0, "https://www.kde.org/applications/utilities/kmousetool/");
-    ADD_ENTRY("org.gnome.clocks",                   0, "https://wiki.gnome.org/Apps/Clocks");
-    ADD_ENTRY("org.kde.filelight",                  1, "https://utils.kde.org/projects/filelight");
-    ADD_ENTRY("org.kde.kcharselect",                0, "https://utils.kde.org/projects/kcharselect/");
-    ADD_ENTRY("org.kde.kdf",                        0, "https://www.kde.org/applications/system/kdiskfree");
-    ADD_ENTRY("org.kde.kfind",                      1, "https://www.kde.org/applications/utilities/kfind/"); // has good filtering options
-    ADD_ENTRY("org.kde.partitionmanager",           0, "https://www.kde.org/applications/system/kdepartitionmanager/");
-    ADD_ENTRY("org.kde.plasma.cuttlefish.kmt-edition", 0, "http://vizzzion.org/blog/2015/02/say-hi-to-cuttlefish/");
-    ADD_ENTRY("org.kde.ksysguard",                  0, "https://userbase.kde.org/KSysGuard");
-    ADD_ENTRY("org.kde.ksystemlog",                 0, "https://www.kde.org/applications/system/ksystemlog/");
-    ADD_ENTRY("org.kde.ktimer",                     0, "https://www.kde.org/applications/utilities/ktimer/");
-    ADD_ENTRY("org.kde.spectacle",                  0, "https://www.kde.org/applications/graphics/spectacle");
-    ADD_ENTRY("simplescreenrecorder",               0, "http://www.maartenbaert.be/simplescreenrecorder/");
-    ADD_ENTRY("shutter",                            0, "http://shutter-project.org"); // good for edit screenshot after capture
-    ADD_ENTRY("vokoscreen",                         0, "https://github.com/vkohaupt/vokoscreen"); // feature-rich screen recorder
-    ADD_ENTRY("xfce4-taskmanager",                  0, "http://goodies.xfce.org/projects/applications/xfce4-taskmanager");
+    ADD_ENTRY(QStringLiteral("angrysearch"),                        0, "https://github.com/DoTheEvo/ANGRYsearch", QString());
+    ADD_ENTRY(QStringLiteral("com.uploadedlobster.peek"),           0, "https://github.com/phw/peek", QStringLiteral("com.uploadedlobster.peek.desktop")); // easy to use screen recorder, creates gif
+    ADD_ENTRY(QStringLiteral("catfish"),                            1, "http://www.twotoasts.de/index.php/catfish/", QStringLiteral("catfish"));
+    ADD_ENTRY(QStringLiteral("ding"),                               0, "https://www-user.tu-chemnitz.de/~fri/ding/", QString()); // Offline dict, Online: http://dict.tu-chemnitz.de/dings.cgi
+    ADD_ENTRY(QStringLiteral("disk"),                               0, "https://en.opensuse.org/YaST_Disk_Controller", QString());
+    ADD_ENTRY(QStringLiteral("fontinst"),                           0, "https://docs.kde.org/trunk5/en/kde-workspace/kcontrol/fontinst/", QString()); // good for previewing many fonts at once
+    ADD_ENTRY(QStringLiteral("fontmatrix"),                         0, "https://github.com/fontmatrix/fontmatrix", QString());
+    ADD_ENTRY(QStringLiteral("fsearch"),                            0, "http://www.fsearch.org/", QString());
+    ADD_ENTRY(QStringLiteral("giggle"),                             1, "https://wiki.gnome.org/Apps/giggle/", QStringLiteral("giggle.desktop")); // good for searching in history
+    ADD_ENTRY(QStringLiteral("git-cola-folder-handler"),            1, "https://git-cola.github.io", QStringLiteral("git-cola.desktop"));
+    ADD_ENTRY(QStringLiteral("git-cola-view-history.kmt-edition"),  1, "https://git-cola.github.io", QStringLiteral("git-cola.desktop"));
+    ADD_ENTRY(QStringLiteral("gitk.kmt-edition"),                   1, "http://git-scm.com/docs/gitk", QString());
+    ADD_ENTRY(QStringLiteral("qgit.kmt-edition"),                   1, "http://libre.tibirna.org/projects/qgit", QString());
+    ADD_ENTRY(QStringLiteral("gitg"),                               1, "https://wiki.gnome.org/action/show/Apps/Gitg?action=show&redirect=Gitg", QStringLiteral("gitg.desktop"));
+    ADD_ENTRY(QStringLiteral("gnome-search-tool"),                  0, "https://help.gnome.org/users/gnome-search-tool/", QStringLiteral("gnome-search-tool.desktop")); // has good filtering options
+    ADD_ENTRY(QStringLiteral("gucharmap"),                          0, "https://wiki.gnome.org/action/show/Apps/Gucharmap", QStringLiteral("gucharmap.desktop"));
+    ADD_ENTRY(QStringLiteral("gparted"),                            0, "http://gparted.org", QStringLiteral("gparted.desktop"));
+    ADD_ENTRY(QStringLiteral("htop"),                               0, "http://hisham.hm/htop/", QStringLiteral("htop.desktop"));
+    ADD_ENTRY(QStringLiteral("hotshots"),                           1, "http://sourceforge.net/projects/hotshots/", QString());
+    ADD_ENTRY(QStringLiteral("kaption"),                            0, "http://kde-apps.org/content/show.php/?content=139302", QString());
+    ADD_ENTRY(QStringLiteral("kding"),                              0, "", QString()); // Offline dict; unmaintained?
+    ADD_ENTRY(QStringLiteral("org.kde.kmousetool"),                 0, "https://www.kde.org/applications/utilities/kmousetool/", QStringLiteral("org.kde.kmousetool"));
+    ADD_ENTRY(QStringLiteral("org.gnome.clocks"),                   0, "https://wiki.gnome.org/Apps/Clocks", QStringLiteral("org.gnome.clocks.desktop"));
+    ADD_ENTRY(QStringLiteral("org.kde.filelight"),                  1, "https://utils.kde.org/projects/filelight", QStringLiteral("org.kde.filelight.desktop"));
+    ADD_ENTRY(QStringLiteral("org.kde.kcharselect"),                0, "https://utils.kde.org/projects/kcharselect/", QStringLiteral("org.kde.kcharselect"));
+    ADD_ENTRY(QStringLiteral("org.kde.kdf"),                        0, "https://www.kde.org/applications/system/kdiskfree", QStringLiteral("org.kde.kdf"));
+    ADD_ENTRY(QStringLiteral("org.kde.kfind"),                      1, "https://www.kde.org/applications/utilities/kfind/", QStringLiteral("org.kde.kfind.desktop")); // has good filtering options
+    ADD_ENTRY(QStringLiteral("org.kde.partitionmanager"),           0, "https://www.kde.org/applications/system/kdepartitionmanager/", QStringLiteral("org.kde.partitionmanager.desktop"));
+    ADD_ENTRY(QStringLiteral("org.kde.plasma.cuttlefish.kmt-edition"), 0, "http://vizzzion.org/blog/2015/02/say-hi-to-cuttlefish/", QStringLiteral("org.kde.plasma.cuttlefish"));
+    ADD_ENTRY(QStringLiteral("org.kde.ksysguard"),                  0, "https://userbase.kde.org/KSysGuard", QStringLiteral("org.kde.ksysguard"));
+    ADD_ENTRY(QStringLiteral("org.kde.ksystemlog"),                 0, "https://www.kde.org/applications/system/ksystemlog/", QStringLiteral("org.kde.ksystemlog"));
+    ADD_ENTRY(QStringLiteral("org.kde.ktimer"),                     0, "https://www.kde.org/applications/utilities/ktimer/", QStringLiteral("org.kde.ktimer"));
+    ADD_ENTRY(QStringLiteral("org.kde.spectacle"),                  0, "https://www.kde.org/applications/graphics/spectacle", QStringLiteral("org.kde.spectacle.desktop"));
+    ADD_ENTRY(QStringLiteral("simplescreenrecorder"),               0, "http://www.maartenbaert.be/simplescreenrecorder/", QStringLiteral("simplescreenrecorder.desktop"));
+    ADD_ENTRY(QStringLiteral("shutter"),                            0, "http://shutter-project.org", QStringLiteral("org.shutterproject.shutter")); // good for edit screenshot after capture
+    ADD_ENTRY(QStringLiteral("vokoscreen"),                         0, "https://github.com/vkohaupt/vokoscreen", QString()); // feature-rich screen recorder
+    ADD_ENTRY(QStringLiteral("xfce4-taskmanager"),                  0, "http://goodies.xfce.org/projects/applications/xfce4-taskmanager", QStringLiteral("xfce4-taskmanager.desktop"));
     //
     // ...definitions end
     //
@@ -108,6 +109,7 @@ KMoreToolsService* KMoreToolsPresets::registerServiceByDesktopEntryName(KMoreToo
         if (service) { // We might get nullptr in case of missing or broken .desktop files
             service->setHomepageUrl(QUrl(kmtServiceInfo.homepageUrl));
             service->setMaxUrlArgCount(kmtServiceInfo.maxUrlArgCount);
+            service->setAppstreamId(kmtServiceInfo.appstreamId);
         }
         return service;
     } else {
@@ -164,7 +166,7 @@ QList<KMoreToolsService*> KMoreToolsPresetsPrivate::registerServicesByGroupingNa
     QSet<QString> alreadyUsedDesktopEntryNames; // including the "more:" keyword
     bool nextIsMore = false;
 
-    Q_FOREACH (const QString &groupingName, groupingNames) {
+    for (const QString &groupingName : groupingNames) {
         auto iter = dict.constFind(groupingName);
         if (iter != dict.constEnd()) {
             Q_FOREACH(const QString &desktopEntryName, *iter) {
@@ -186,12 +188,12 @@ QList<KMoreToolsService*> KMoreToolsPresetsPrivate::registerServicesByGroupingNa
                 }
             }
         } else {
-            qWarning() << "KMoreToolsPresets::registerServicesByGroupingName: groupingName not found: " << groupingName;
+            qCWarning(KNEWSTUFF) << "KMoreToolsPresets::registerServicesByGroupingName: groupingName not found: " << groupingName;
         }
     }
 
     if (resultList.isEmpty()) {
-        qWarning() << "KMoreToolsPresets::registerServicesByGroupingName: " << groupingNames << ". Nothing found in this groupings. HINT: check for invalid grouping names.";
+        qCWarning(KNEWSTUFF) << "KMoreToolsPresets::registerServicesByGroupingName: " << groupingNames << ". Nothing found in this groupings. HINT: check for invalid grouping names.";
     }
 
     return resultList;
